[PATCH 1/2] drm/i915/wopcm: update default size for gen11+

Daniele Ceraolo Spurio daniele.ceraolospurio at intel.com
Tue Jun 4 22:40:00 UTC 2019


The size has been increased to 2MB starting from gen11. GuC and HuC FWs
fit in 1MB so we were fine even with the legacy define, but let's still
move to the correct one before the blobs grow to avoid being caught off
guard in the future.

Bspec: 44982
Signed-off-by: Daniele Ceraolo Spurio <daniele.ceraolospurio at intel.com>
Cc: Michal Wajdeczko <michal.wajdeczko at intel.com>
---
 drivers/gpu/drm/i915/intel_wopcm.c | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/drivers/gpu/drm/i915/intel_wopcm.c b/drivers/gpu/drm/i915/intel_wopcm.c
index f82a415ea2ba..6cb993eea206 100644
--- a/drivers/gpu/drm/i915/intel_wopcm.c
+++ b/drivers/gpu/drm/i915/intel_wopcm.c
@@ -41,8 +41,9 @@
  * context).
  */
 
 /* Default WOPCM size 1MB. */
 #define GEN9_WOPCM_SIZE			(1024 * 1024)
 /* 16KB WOPCM (RSVD WOPCM) is reserved from HuC firmware top. */
 #define WOPCM_RESERVED_SIZE		(16 * 1024)
 
@@ -71,7 +72,10 @@
  */
 void intel_wopcm_init_early(struct intel_wopcm *wopcm)
 {
-	wopcm->size = GEN9_WOPCM_SIZE;
+	if (INTEL_GEN(wopcm_to_i915(wopcm)) >= 11)
+		wopcm->size = GEN11_WOPCM_SIZE;
+	else
+		wopcm->size = GEN9_WOPCM_SIZE;
 
 	DRM_DEBUG_DRIVER("WOPCM size: %uKiB\n", wopcm->size / 1024);
 }
@@ -41,8 +41,9 @@
  */
 
-/* Default WOPCM size 1MB. */
-#define GEN9_WOPCM_SIZE			(1024 * 1024)
+/* Default WOPCM size is 2MB from gen11, 1MB on previous platforms */
+#define GEN11_WOPCM_SIZE		(SZ_2M)
+#define GEN9_WOPCM_SIZE			(SZ_1M)
 /* 16KB WOPCM (RSVD WOPCM) is reserved from HuC firmware top. */
 #define WOPCM_RESERVED_SIZE		(16 * 1024)
-- 
2.20.1



More information about the Intel-gfx-trybot mailing list